@@ -4,7 +4,6 @@ def docxToPdf(directory):
   files = os.listdir(directory)
   for ids,f in enumerate(files):
     f_name, f_ext = os.path.splitext(f)
-    # Показываю инфо о файлах
     name = '{} {} {}'.format(ids+1,f_name, f_ext)
     print(name)
   convert(directory+'/')
@@ -19,14 +18,18 @@ def check_tables(directory, numTable):
   document_out = Document() # новый документ с таблицами 0 всех файлов
   text1 = 'таблицы {} из всех РПД'.format(numTable)
   document_out.add_paragraph(text1)
-  for ids, rpd in enumerate(listSortedNatural): #натурально 1 10 2 как 1 2 10
+  for ids, rpd in enumerate(listSortedNatural): 
+    f_name, f_ext = os.path.splitext(rpd)
+    if f_ext != ".docx":
+      print("Не docx file: {}".format(rpd))
+      continue
     text2 = 'Файл '+str(ids+1)
     document_out.add_paragraph(text2)
     document_out.add_paragraph(rpd)  #print(rpd)
     doc_document = os.path.join(directory, rpd)
     document = Document(doc_document)
     for k, table in enumerate(document.tables):
-      if k = = numTable-1:
+      if k == numTable-1:
         template0 = document.tables[numTable]
         tbl0 = template0._tbl
         new_tbl0 = copy.deepcopy(tbl0)
